# bioio-base

[![Build Status](https://github.com/bioio-devs/bioio-base/actions/workflows/ci.yml/badge.svg)](https://github.com/bioio-devs/bioio-base/actions)
[![Documentation](https://github.com/bioio-devs/bioio-base/actions/workflows/docs.yml/badge.svg)](https://bioio-devs.github.io/bioio-base)
[![PyPI version](https://badge.fury.io/py/bioio-base.svg)](https://badge.fury.io/py/bioio-base)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![Python 3.9+](https://img.shields.io/badge/python-3.9,3.10,3.11-blue.svg)](https://www.python.org/downloads/release/python-390/)

Typing, base classes, and more for BioIO projects.

---

## Documentation

This package exists to provide common utilities and base classes for which BioIO reader plugins can utilize to reduce boilerplate code.

[See the full documentation on our GitHub pages site](https://bioio-devs.github.io/bioio/OVERVIEW.html) - the generic use and installation instructions there will work for this package.

## Installation

**Stable Release:** `pip install bioio-base`<br>
**Development Head:** `pip install git+https://github.com/bioio-devs/bioio-base.git`

## Issues
[_Click here to view all open issues in bioio-devs organization at once_](https://github.com/search?q=user%3Abioio-devs+is%3Aissue+is%3Aopen&type=issues&ref=advsearch) or check this repository's issue tab.


## Development

See [CONTRIBUTING.md](CONTRIBUTING.md) for information related to developing the code.
